# Instructions

### This is test project.

### Please install this package
'''
pip install functions-by-rybitska
'''

### You can install older version
```
pip install functions-by-rybitska==VERSION_NUMBER
```